[gcompris] macosx: adapded the build chain to python 2.7 and gstreamer instead of SDL.



commit 05aadc819f66801b2e18fb2b265456472f8cf211
Author: Bruno Coudoin <bruno coudoin gcompris net>
Date:   Sun Jul 1 21:21:46 2012 +0200

    macosx: adapded the build chain to python 2.7 and gstreamer instead of SDL.

 macosx/GComprisAdmin    |    2 +-
 macosx/configure_mac.sh |    4 ++--
 macosx/gcompris.bundle  |   28 ++++++++++++++++------------
 macosx/launcher.sh      |    7 +++++--
 4 files changed, 24 insertions(+), 17 deletions(-)
---
diff --git a/macosx/GComprisAdmin b/macosx/GComprisAdmin
index 6efa8fb..4d9bd90 100755
--- a/macosx/GComprisAdmin
+++ b/macosx/GComprisAdmin
@@ -35,7 +35,7 @@ export GTK_IM_MODULE_FILE="$bundle_etc/gtk-2.0/gtk.immodules"
 export GDK_PIXBUF_MODULE_FILE="$bundle_etc/gtk-2.0/gdk-pixbuf.loaders"
 export PANGO_RC_FILE="$bundle_etc/pango/pangorc"
 
-export PYTHONPATH=$bundle_lib/python2.6/site-packages:$bundle_lib/python2.6/site-packages/gtk-2.0/:$bundle_lib/python2.6:$bundle_lib/python2.6/plat-darwin:$bundle_lib/python2.6/plat-mac:$bundle_lib/python2.6/lib-dynload
+export PYTHONPATH=$bundle_lib/python2.7/site-packages:$bundle_lib/python2.7/site-packages/gtk-2.0/:$bundle_lib/python2.7:$bundle_lib/python2.7/plat-darwin:$bundle_lib/python2.7/plat-mac:$bundle_lib/python2.7/lib-dynload
 
 APP=gcompris
 I18NDIR="$bundle_data/locale"
diff --git a/macosx/configure_mac.sh b/macosx/configure_mac.sh
index 196a4da..3d82cc1 100755
--- a/macosx/configure_mac.sh
+++ b/macosx/configure_mac.sh
@@ -1,4 +1,4 @@
 cd ..
-export PYTHONPATH=/Users/bruno/gtk/inst/lib/python2.6/site-packages
-./configure --prefix /Users/bruno/gtk/inst/ --libdir /Users/bruno/gtk/inst/lib --enable-shared --disable-static --enable-gnet --enable-py-build-only --with-python=/Users/bruno/gtk/inst/bin/python --enable-nsbundle --enable-sdlmixer --disable-binreloc
+export PYTHONPATH=$HOME/gtk/inst/lib/python2.7/site-packages
+./configure --prefix $HOME/gtk/inst/ --libdir $HOME/gtk/inst/lib --enable-shared --disable-static --enable-gnet --enable-py-build-only --with-python=$HOME/gtk/inst/bin/python --enable-nsbundle --disable-binreloc
 
diff --git a/macosx/gcompris.bundle b/macosx/gcompris.bundle
index 1ea0ee0..bc709a9 100644
--- a/macosx/gcompris.bundle
+++ b/macosx/gcompris.bundle
@@ -55,44 +55,44 @@
        binaries link to are also copied in automatically.
   -->
   <binary>
-    ${prefix}/lib/gtk-2.0/${pkg:gtk+-2.0:gtk_binary_version}/loaders/*.so
+    ${prefix}/lib/gdk-pixbuf-2.0/${pkg:gtk+-2.0:gtk_binary_version}/loaders/*.so
   </binary>
 
   <binary>
-    ${prefix}/lib/python2.6/site-packages/cairo/*.so
+    ${prefix}/lib/python2.7/site-packages/cairo/*.so
   </binary>
 
   <binary>
-    ${prefix}/lib/python2.6/site-packages/gtk-2.0/gtk/*.so
+    ${prefix}/lib/python2.7/site-packages/gtk-2.0/gtk/*.so
   </binary>
 
   <binary>
-    ${prefix}/lib/python2.6/site-packages/gtk-2.0/gio/*.so
+    ${prefix}/lib/python2.7/site-packages/gtk-2.0/gio/*.so
   </binary>
 
   <binary>
-    ${prefix}/lib/python2.6/site-packages/gtk-2.0/glib/*.so
+    ${prefix}/lib/libogg*.dylib
   </binary>
 
   <binary>
-    ${prefix}/lib/python2.6/site-packages/gtk-2.0/gobject/*.so
+    ${prefix}/lib/libvorbis*.dylib
   </binary>
 
   <binary>
-    ${prefix}/bin/gcompris-gnuchess
+    ${prefix}/lib/gstreamer-0.10/*
   </binary>
 
   <binary>
-    ${prefix}/bin/gnucap
+    ${prefix}/libexec/gstreamer-0.10/*
   </binary>
 
-  <!-- SDL -->
+
   <binary>
-    ${prefix}/lib/libvorbisfile.dylib
+    ${prefix}/bin/gcompris-gnuchess
   </binary>
 
   <binary>
-    ${prefix}/lib/libpyglib-2.0-python.dylib
+    ${prefix}/bin/gnucap
   </binary>
 
   <!-- GCompris plugins -->
@@ -120,7 +120,11 @@
   </data>
 
   <data>
-    ${prefix}/lib/python2.6
+    ${prefix}/lib/python2.7
+  </data>
+
+  <data>
+    ${prefix}/include/python2.7/pyconfig.h
   </data>
 
   <!-- Copy in the themes data. You may want to trim this to save space
diff --git a/macosx/launcher.sh b/macosx/launcher.sh
index 609a144..ba2def7 100755
--- a/macosx/launcher.sh
+++ b/macosx/launcher.sh
@@ -34,6 +34,9 @@ export GTK_IM_MODULE_FILE="$bundle_etc/gtk-2.0/gtk.immodules"
 export GDK_PIXBUF_MODULE_FILE="$bundle_etc/gtk-2.0/gdk-pixbuf.loaders"
 export PANGO_RC_FILE="$bundle_etc/pango/pangorc"
 
+export GST_PLUGIN_SYSTEM_PATH=$bundle_res
+export GST_PLUGIN_SCANNER=$bundle_res/libexec/gstreamer-0.10/gst-plugin-scanner
+export PYTHONHOME=$bundle_res
 export PYTHONPATH=$bundle_lib/python2.7/site-packages:$bundle_lib/python2.7/site-packages/gtk-2.0/:$bundle_lib/python2.7:$bundle_lib/python2.7/plat-darwin:$bundle_lib/python2.7/plat-mac:$bundle_lib/python2.7/lib-dynload
 
 APP=gcompris
@@ -112,13 +115,13 @@ if test -n $LANG; then
 #bit matches $LANG
     elif test $LANG == ${APPLELOCALE:0:2} -a $APPLELOCALE > ${APPLELOCALE:0:2}; then
 	export LC_MESSAGES=${APPLELOCALE:0:5}
 #Fail. Get a list of the locales in $PREFIX/share/locale that match
 #our two letter language code and pick the first one, special casing
 #english to set en_US
     elif test $LANG == "en"; then
 	export LC_MESSAGES="en_US"
     else
-	LOC=`find $PREFIX/share/locale -name $LANG???`
+	LOC=`find $bundle_res/share/locale -name $LANG???`
 	for L in $LOC; do
 	    export LC_MESSAGES=$L
 	done
@@ -112,13 +115,13 @@ if test -n $LANG; then
     elif test $LANG == ${APPLELOCALE:0:2} -a $APPLELOCALE > ${APPLELOCALE:0:2}; then
 	export LC_MESSAGES=${APPLELOCALE:0:5}
-#Fail. Get a list of the locales in $PREFIX/share/locale that match
+#Fail. Get a list of the locales in $bundle_res/share/locale that match
 #our two letter language code and pick the first one, special casing
 #english to set en_US



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]